pub struct DeadLetterItem {
pub attempt_id: String,
pub run_id: String,
pub attempt_no: u32,
pub terminal_status: String,
pub reason: Option<String>,
pub dead_at: String,
pub replay_status: String,
pub replay_count: u32,
pub last_replayed_at: Option<String>,
}Available on crate feature
execution-server only.Fields
attempt_id: Stringrun_id: Stringattempt_no: u32terminal_status: Stringreason: Option<String>dead_at: Stringreplay_status: Stringreplay_count: u32last_replayed_at: Option<String>Trait Implementations
Sourceimpl Clone for DeadLetterItem
impl Clone for DeadLetterItem
Sourcefn clone(&self) -> DeadLetterItem
fn clone(&self) -> DeadLetterItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeadLetterItem
impl Debug for DeadLetterItem
Sourceimpl JsonSchema for DeadLetterItem
impl JsonSchema for DeadLetterItem
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DeadLetterItem
impl Serialize for DeadLetterItem
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more