pub struct DeadLetterReplayResponse {
pub attempt_id: String,
pub status: String,
pub replay_count: u32,
}Available on crate feature
execution-server only.Fields
attempt_id: Stringstatus: Stringreplay_count: u32Trait Implementations
Sourceimpl Clone for DeadLetterReplayResponse
impl Clone for DeadLetterReplayResponse
Sourcefn clone(&self) -> DeadLetterReplayResponse
fn clone(&self) -> DeadLetterReplayResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeadLetterReplayResponse
impl Debug for DeadLetterReplayResponse
Sourceimpl JsonSchema for DeadLetterReplayResponse
impl JsonSchema for DeadLetterReplayResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DeadLetterReplayResponse
impl Serialize for DeadLetterReplayResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more