pub struct JobDetailResponse {
pub thread_id: String,
pub status: String,
pub checkpoint_id: Option<String>,
pub values: Value,
pub history: Vec<JobHistoryItem>,
pub timeline: Vec<JobTimelineItem>,
pub pending_interrupt: Option<InterruptDetailResponse>,
pub trace: Option<TraceContextResponse>,
pub observability: Option<KernelObservability>,
}Available on crate feature
execution-server only.Fields
thread_id: Stringstatus: Stringcheckpoint_id: Option<String>values: Valuehistory: Vec<JobHistoryItem>timeline: Vec<JobTimelineItem>pending_interrupt: Option<InterruptDetailResponse>trace: Option<TraceContextResponse>observability: Option<KernelObservability>Trait Implementations
Sourceimpl Clone for JobDetailResponse
impl Clone for JobDetailResponse
Sourcefn clone(&self) -> JobDetailResponse
fn clone(&self) -> JobDetailResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JobDetailResponse
impl Debug for JobDetailResponse
Sourceimpl JsonSchema for JobDetailResponse
impl JsonSchema for JobDetailResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for JobDetailResponse
impl Serialize for JobDetailResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more