pub struct JobStateResponse {
pub thread_id: String,
pub checkpoint_id: Option<String>,
pub created_at: String,
pub values: Value,
}Available on crate feature
execution-server only.Fields
thread_id: Stringcheckpoint_id: Option<String>created_at: Stringvalues: ValueTrait Implementations
Sourceimpl Clone for JobStateResponse
impl Clone for JobStateResponse
Sourcefn clone(&self) -> JobStateResponse
fn clone(&self) -> JobStateResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JobStateResponse
impl Debug for JobStateResponse
Sourceimpl JsonSchema for JobStateResponse
impl JsonSchema for JobStateResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for JobStateResponse
impl Serialize for JobStateResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more