pub struct ListAuditLogsQuery {
pub request_id: Option<String>,
pub action: Option<String>,
pub from_ms: Option<i64>,
pub to_ms: Option<i64>,
pub limit: Option<usize>,
}Available on crate feature
execution-server only.Fields
request_id: Option<String>action: Option<String>from_ms: Option<i64>to_ms: Option<i64>limit: Option<usize>Trait Implementations
Sourceimpl Clone for ListAuditLogsQuery
impl Clone for ListAuditLogsQuery
Sourcefn clone(&self) -> ListAuditLogsQuery
fn clone(&self) -> ListAuditLogsQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListAuditLogsQuery
impl Debug for ListAuditLogsQuery
Sourceimpl<'de> Deserialize<'de> for ListAuditLogsQuery
impl<'de> Deserialize<'de> for ListAuditLogsQuery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ListAuditLogsQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ListAuditLogsQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListAuditLogsQuery
impl JsonSchema for ListAuditLogsQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListAuditLogsQuery
impl RefUnwindSafe for ListAuditLogsQuery
impl Send for ListAuditLogsQuery
impl Sync for ListAuditLogsQuery
impl Unpin for ListAuditLogsQuery
impl UnsafeUnpin for ListAuditLogsQuery
impl UnwindSafe for ListAuditLogsQuery