pub struct ListDeadLettersQuery {
pub status: Option<String>,
pub limit: Option<usize>,
}Available on crate feature
execution-server only.Fields
status: Option<String>limit: Option<usize>Trait Implementations
Sourceimpl Clone for ListDeadLettersQuery
impl Clone for ListDeadLettersQuery
Sourcefn clone(&self) -> ListDeadLettersQuery
fn clone(&self) -> ListDeadLettersQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDeadLettersQuery
impl Debug for ListDeadLettersQuery
Sourceimpl<'de> Deserialize<'de> for ListDeadLettersQuery
impl<'de> Deserialize<'de> for ListDeadLettersQuery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ListDeadLettersQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ListDeadLettersQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListDeadLettersQuery
impl JsonSchema for ListDeadLettersQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListDeadLettersQuery
impl RefUnwindSafe for ListDeadLettersQuery
impl Send for ListDeadLettersQuery
impl Sync for ListDeadLettersQuery
impl Unpin for ListDeadLettersQuery
impl UnsafeUnpin for ListDeadLettersQuery
impl UnwindSafe for ListDeadLettersQuery