pub struct ListInterruptsQuery {
pub status: Option<String>,
pub run_id: Option<String>,
pub limit: Option<usize>,
}Available on crate feature
execution-server only.Fields
status: Option<String>run_id: Option<String>limit: Option<usize>Trait Implementations
Sourceimpl Clone for ListInterruptsQuery
impl Clone for ListInterruptsQuery
Sourcefn clone(&self) -> ListInterruptsQuery
fn clone(&self) -> ListInterruptsQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListInterruptsQuery
impl Debug for ListInterruptsQuery
Sourceimpl<'de> Deserialize<'de> for ListInterruptsQuery
impl<'de> Deserialize<'de> for ListInterruptsQuery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ListInterruptsQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ListInterruptsQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListInterruptsQuery
impl JsonSchema for ListInterruptsQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListInterruptsQuery
impl RefUnwindSafe for ListInterruptsQuery
impl Send for ListInterruptsQuery
impl Sync for ListInterruptsQuery
impl Unpin for ListInterruptsQuery
impl UnsafeUnpin for ListInterruptsQuery
impl UnwindSafe for ListInterruptsQuery