pub struct RejectInterruptRequest {
pub reason: Option<String>,
}Available on crate feature
execution-server only.Fields
reason: Option<String>Trait Implementations
Sourceimpl Clone for RejectInterruptRequest
impl Clone for RejectInterruptRequest
Sourcefn clone(&self) -> RejectInterruptRequest
fn clone(&self) -> RejectInterruptRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RejectInterruptRequest
impl Debug for RejectInterruptRequest
Sourceimpl<'de> Deserialize<'de> for RejectInterruptRequest
impl<'de> Deserialize<'de> for RejectInterruptRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RejectInterruptRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RejectInterruptRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RejectInterruptRequest
impl JsonSchema for RejectInterruptRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RejectInterruptRequest
impl RefUnwindSafe for RejectInterruptRequest
impl Send for RejectInterruptRequest
impl Sync for RejectInterruptRequest
impl Unpin for RejectInterruptRequest
impl UnsafeUnpin for RejectInterruptRequest
impl UnwindSafe for RejectInterruptRequest