pub struct ReplayJobRequest {
pub checkpoint_id: Option<String>,
}Available on crate feature
execution-server only.Fields
checkpoint_id: Option<String>Trait Implementations
Sourceimpl Clone for ReplayJobRequest
impl Clone for ReplayJobRequest
Sourcefn clone(&self) -> ReplayJobRequest
fn clone(&self) -> ReplayJobRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplayJobRequest
impl Debug for ReplayJobRequest
Sourceimpl<'de> Deserialize<'de> for ReplayJobRequest
impl<'de> Deserialize<'de> for ReplayJobRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ReplayJobRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ReplayJobRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReplayJobRequest
impl JsonSchema for ReplayJobRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReplayJobRequest
impl RefUnwindSafe for ReplayJobRequest
impl Send for ReplayJobRequest
impl Sync for ReplayJobRequest
impl Unpin for ReplayJobRequest
impl UnsafeUnpin for ReplayJobRequest
impl UnwindSafe for ReplayJobRequest