pub struct ResumeJobRequest {
pub value: Value,
pub checkpoint_id: Option<String>,
}Available on crate feature
execution-server only.Fields
value: Valuecheckpoint_id: Option<String>Trait Implementations
Sourceimpl Clone for ResumeJobRequest
impl Clone for ResumeJobRequest
Sourcefn clone(&self) -> ResumeJobRequest
fn clone(&self) -> ResumeJobRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResumeJobRequest
impl Debug for ResumeJobRequest
Sourceimpl<'de> Deserialize<'de> for ResumeJobRequest
impl<'de> Deserialize<'de> for ResumeJobRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ResumeJobRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ResumeJobRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResumeJobRequest
impl JsonSchema for ResumeJobRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResumeJobRequest
impl RefUnwindSafe for ResumeJobRequest
impl Send for ResumeJobRequest
impl Sync for ResumeJobRequest
impl Unpin for ResumeJobRequest
impl UnsafeUnpin for ResumeJobRequest
impl UnwindSafe for ResumeJobRequest