pub struct RetryPolicyRequest {
pub strategy: String,
pub backoff_ms: i64,
pub max_backoff_ms: Option<i64>,
pub multiplier: Option<f64>,
pub max_retries: u32,
}Available on crate feature
execution-server only.Fields
strategy: Stringbackoff_ms: i64max_backoff_ms: Option<i64>multiplier: Option<f64>max_retries: u32Trait Implementations
Sourceimpl Clone for RetryPolicyRequest
impl Clone for RetryPolicyRequest
Sourcefn clone(&self) -> RetryPolicyRequest
fn clone(&self) -> RetryPolicyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetryPolicyRequest
impl Debug for RetryPolicyRequest
Sourceimpl<'de> Deserialize<'de> for RetryPolicyRequest
impl<'de> Deserialize<'de> for RetryPolicyRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RetryPolicyRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RetryPolicyRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RetryPolicyRequest
impl JsonSchema for RetryPolicyRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RetryPolicyRequest
impl Serialize for RetryPolicyRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more