pub struct RunJobRequest {
pub thread_id: String,
pub input: Option<String>,
pub idempotency_key: Option<String>,
pub timeout_policy: Option<TimeoutPolicyRequest>,
pub priority: Option<i32>,
pub tenant_id: Option<String>,
}Available on crate feature
execution-server only.Fields
thread_id: Stringinput: Option<String>idempotency_key: Option<String>timeout_policy: Option<TimeoutPolicyRequest>priority: Option<i32>tenant_id: Option<String>Trait Implementations
Sourceimpl Clone for RunJobRequest
impl Clone for RunJobRequest
Sourcefn clone(&self) -> RunJobRequest
fn clone(&self) -> RunJobRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunJobRequest
impl Debug for RunJobRequest
Sourceimpl<'de> Deserialize<'de> for RunJobRequest
impl<'de> Deserialize<'de> for RunJobRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RunJobRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RunJobRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunJobRequest
impl JsonSchema for RunJobRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunJobRequest
impl RefUnwindSafe for RunJobRequest
impl Send for RunJobRequest
impl Sync for RunJobRequest
impl Unpin for RunJobRequest
impl UnsafeUnpin for RunJobRequest
impl UnwindSafe for RunJobRequest