pub struct TimelineExportResponse {
pub thread_id: String,
pub timeline: Vec<JobTimelineItem>,
pub history: Vec<JobHistoryItem>,
pub observability: Option<KernelObservability>,
pub trace: Option<TraceContextResponse>,
}Available on crate feature
execution-server only.Fields
thread_id: Stringtimeline: Vec<JobTimelineItem>history: Vec<JobHistoryItem>observability: Option<KernelObservability>trace: Option<TraceContextResponse>Trait Implementations
Sourceimpl Clone for TimelineExportResponse
impl Clone for TimelineExportResponse
Sourcefn clone(&self) -> TimelineExportResponse
fn clone(&self) -> TimelineExportResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimelineExportResponse
impl Debug for TimelineExportResponse
Sourceimpl JsonSchema for TimelineExportResponse
impl JsonSchema for TimelineExportResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TimelineExportResponse
impl Serialize for TimelineExportResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more