pub struct TimeoutPolicyRequest {
pub timeout_ms: i64,
pub on_timeout_status: String,
}Available on crate feature
execution-server only.Fields
timeout_ms: i64on_timeout_status: StringTrait Implementations
Sourceimpl Clone for TimeoutPolicyRequest
impl Clone for TimeoutPolicyRequest
Sourcefn clone(&self) -> TimeoutPolicyRequest
fn clone(&self) -> TimeoutPolicyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimeoutPolicyRequest
impl Debug for TimeoutPolicyRequest
Sourceimpl<'de> Deserialize<'de> for TimeoutPolicyRequest
impl<'de> Deserialize<'de> for TimeoutPolicyRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TimeoutPolicyRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TimeoutPolicyRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TimeoutPolicyRequest
impl JsonSchema for TimeoutPolicyRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TimeoutPolicyRequest
impl Serialize for TimeoutPolicyRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more