pub struct TraceContextResponse {
pub trace_id: String,
pub span_id: String,
pub parent_span_id: Option<String>,
pub traceparent: String,
}Available on crate feature
execution-server only.Fields
trace_id: Stringspan_id: Stringparent_span_id: Option<String>traceparent: StringTrait Implementations
Sourceimpl Clone for TraceContextResponse
impl Clone for TraceContextResponse
Sourcefn clone(&self) -> TraceContextResponse
fn clone(&self) -> TraceContextResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceContextResponse
impl Debug for TraceContextResponse
Sourceimpl<'de> Deserialize<'de> for TraceContextResponse
impl<'de> Deserialize<'de> for TraceContextResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TraceContextResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TraceContextResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TraceContextResponse
impl JsonSchema for TraceContextResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TraceContextResponse
impl PartialEq for TraceContextResponse
Sourceimpl Serialize for TraceContextResponse
impl Serialize for TraceContextResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for TraceContextResponse
impl StructuralPartialEq for TraceContextResponse