pub struct WorkerAckRequest {
pub attempt_id: String,
pub terminal_status: String,
pub retry_policy: Option<RetryPolicyRequest>,
}Available on crate feature
execution-server only.Fields
attempt_id: Stringterminal_status: Stringretry_policy: Option<RetryPolicyRequest>Trait Implementations
Sourceimpl Clone for WorkerAckRequest
impl Clone for WorkerAckRequest
Sourcefn clone(&self) -> WorkerAckRequest
fn clone(&self) -> WorkerAckRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerAckRequest
impl Debug for WorkerAckRequest
Sourceimpl<'de> Deserialize<'de> for WorkerAckRequest
impl<'de> Deserialize<'de> for WorkerAckRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<WorkerAckRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<WorkerAckRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerAckRequest
impl JsonSchema for WorkerAckRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerAckRequest
impl RefUnwindSafe for WorkerAckRequest
impl Send for WorkerAckRequest
impl Sync for WorkerAckRequest
impl Unpin for WorkerAckRequest
impl UnsafeUnpin for WorkerAckRequest
impl UnwindSafe for WorkerAckRequest