pub struct WorkerHeartbeatRequest {
pub lease_id: String,
pub lease_ttl_seconds: Option<i64>,
}Available on crate feature
execution-server only.Fields
lease_id: Stringlease_ttl_seconds: Option<i64>Trait Implementations
Sourceimpl Clone for WorkerHeartbeatRequest
impl Clone for WorkerHeartbeatRequest
Sourcefn clone(&self) -> WorkerHeartbeatRequest
fn clone(&self) -> WorkerHeartbeatRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerHeartbeatRequest
impl Debug for WorkerHeartbeatRequest
Sourceimpl<'de> Deserialize<'de> for WorkerHeartbeatRequest
impl<'de> Deserialize<'de> for WorkerHeartbeatRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<WorkerHeartbeatRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<WorkerHeartbeatRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerHeartbeatRequest
impl JsonSchema for WorkerHeartbeatRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerHeartbeatRequest
impl RefUnwindSafe for WorkerHeartbeatRequest
impl Send for WorkerHeartbeatRequest
impl Sync for WorkerHeartbeatRequest
impl Unpin for WorkerHeartbeatRequest
impl UnsafeUnpin for WorkerHeartbeatRequest
impl UnwindSafe for WorkerHeartbeatRequest