pub struct WorkerPollResponse {
pub decision: String,
pub attempt_id: Option<String>,
pub lease_id: Option<String>,
pub lease_expires_at: Option<String>,
pub reason: Option<String>,
pub worker_active_leases: Option<usize>,
pub worker_limit: Option<usize>,
pub tenant_id: Option<String>,
pub tenant_active_leases: Option<usize>,
pub tenant_limit: Option<usize>,
pub trace: Option<TraceContextResponse>,
}Available on crate feature
execution-server only.Fields
decision: Stringattempt_id: Option<String>lease_id: Option<String>lease_expires_at: Option<String>reason: Option<String>worker_active_leases: Option<usize>worker_limit: Option<usize>tenant_id: Option<String>tenant_active_leases: Option<usize>tenant_limit: Option<usize>trace: Option<TraceContextResponse>Trait Implementations
Sourceimpl Clone for WorkerPollResponse
impl Clone for WorkerPollResponse
Sourcefn clone(&self) -> WorkerPollResponse
fn clone(&self) -> WorkerPollResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerPollResponse
impl Debug for WorkerPollResponse
Sourceimpl JsonSchema for WorkerPollResponse
impl JsonSchema for WorkerPollResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for WorkerPollResponse
impl Serialize for WorkerPollResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more