pub struct WorkerReportStepRequest {
pub attempt_id: String,
pub action_id: String,
pub status: String,
pub dedupe_token: String,
}Available on crate feature
execution-server only.Fields
attempt_id: Stringaction_id: Stringstatus: Stringdedupe_token: StringTrait Implementations
Sourceimpl Clone for WorkerReportStepRequest
impl Clone for WorkerReportStepRequest
Sourcefn clone(&self) -> WorkerReportStepRequest
fn clone(&self) -> WorkerReportStepRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkerReportStepRequest
impl Debug for WorkerReportStepRequest
Sourceimpl<'de> Deserialize<'de> for WorkerReportStepRequest
impl<'de> Deserialize<'de> for WorkerReportStepRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<WorkerReportStepRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<WorkerReportStepRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkerReportStepRequest
impl JsonSchema for WorkerReportStepRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkerReportStepRequest
impl RefUnwindSafe for WorkerReportStepRequest
impl Send for WorkerReportStepRequest
impl Sync for WorkerReportStepRequest
impl Unpin for WorkerReportStepRequest
impl UnsafeUnpin for WorkerReportStepRequest
impl UnwindSafe for WorkerReportStepRequest